@@ -22,15 +22,3 @@ class BaseModel:
             # which does not have a scenario.description attribute.
             return getattr(self._data, key, None)
         return getattr(self._data, key)
-
-
-class BaseFeature(BaseModel):
-    """Feature base for parsers."""
-
-    def __init__(self, root_path, source_path):
-        self._data = None
-
-    @property
-    def examples(self):
-        """Supports feature-level examples in some parsers."""
-        return []
